# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [TODO]

- [docs] create a logo
- [docs] fill out project maturity card
- [feat] cli option to remove obsolete snapshots from within snapshot file
- [feat] support rich diffs for large snapshots
- [chore] setup tox for python 3.6 -> 3.8 support
- [chore] publish package

## [Unreleased]

- [feat] support --update-snapshots cli flag to write snapshots
- [feat] support custom plugins for writing snapshots, inc. image plugin
